@@ -4,13 +4,15 @@ import os
 import random
 import sys
 
+import dateutil.parser
+
 # Python 2.x compabitlity
 if sys.version[0] == '2':
     FileNotFoundError = IOError
 
 TEMPLATE = u"""MIME-Version: 1.0
 Date: {}
-Subject: [{}] {}
+Subject: {}
 From: {}
 Content-Type: text/plain
 
@@ -39,21 +41,12 @@ class Converter:
             self.output('WARNING: database is malformed and will be ignored')
             self.dbdata = None
 
-        inval = []
-        for feed, content in self.feeds.items():
-            try: # to validate the feeds, access some essential keys
-                content['feed']['title']
-                content['feed']['link']
-                content['feed']['updated']
-            except:
-                self.output('WARNING: feed {} seems to be broken'.format(feed))
-                inval.append(feed)
-        for i in inval: # pop invalid feeds
-            self.feeds.pop(i)
-
     def writeout(self):
         """Check which updates need to be written to the maildir"""
-        if not os.access(self.maildir, os.W_OK):
+        if (not os.access(self.maildir, os.W_OK)
+            or not os.access(self.maildir + '/tmp', os.W_OK)
+            or not os.access(self.maildir + '/new', os.W_OK)
+            or not os.access(self.maildir + '/cur', os.W_OK)):
             try: # to make the maildir
                 os.mkdir(self.maildir)
                 os.mkdir('{}/tmp'.format(self.maildir))
@@ -63,20 +56,33 @@ class Converter:
                 sys.exit('ERROR: accessing "{}" failed'.format(self.maildir))
 
         newtimes = {}
-        for feed, content in self.feeds.items():
+        for feed in self.feeds:
+            title = feed.feed.title
             try: # to find the last update time for the feed in the db
-                pubdate = self.mktime(self.dbdata[feed])
+                pubdate = self.mktime(self.dbdata[title])
             except: # there is no record, mail all entries
                 pubdate = None
-            for entry in content['entries']:
-                time = self.mktime(entry['published'])
-                if not pubdate or time > pubdate:
-                    mail = TEMPLATE.format(entry['published'],
-                    entry['author'], entry['title'], feed, entry['link'],
-                    entry['description'])
+            for entry in feed.entries:
+                try:
+                    time = entry.updated
+                except:
+                    try:
+                        time = entry.published
+                    except:
+                        pass
+                if time:
+                    dtime = self.mktime(time)
+                if not pubdate or dtime > pubdate:
+                    mail = ''
+                    try:
+                        mail = TEMPLATE.format(time, entry.title,
+                        feed, entry.link, entry.description)
+                    except:
+                        print(feed, entry)
                     self.write(mail)
-                if feed not in newtimes or time > self.mktime(newtimes[feed]):
-                    newtimes[feed] = entry['published']
+                if (feed not in newtimes
+                    or dtime > self.mktime(newtimes[title])):
+                    newtimes[title] = time
 
         try: # to write the new database
             with open(self.db, 'w') as f:
@@ -103,9 +109,7 @@ class Converter:
 
     def mktime(self, arg):
         """Make a datetime object from a time string"""
-        # This is due to the fantastic built-in strptime >.<
-        return datetime.datetime.strptime(' '.join(arg.split(' ')[0:5]),
-                                          '%a, %d %b %Y %X')
+        return dateutil.parser.parse(arg)
 
     def output(self, arg):
         if not self.silent:
